@@ -6,10 +6,20 @@
  * Daniel.Veillard@imag.fr
  */
 
-#include <string.h>
-#include <sys/time.h>
-#include <unistd.h>
 #include <libxml/xmlversion.h>
+#include <libxslt/xsltconfig.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 #include <libxml/xmlmemory.h>
 #include <libxml/debugXML.h>
 #include <libxml/HTMLtree.h>
@@ -20,6 +30,9 @@
 #ifdef LIBXML_XINCLUDE_ENABLED
 #include <libxml/xinclude.h>
 #endif
+#ifdef LIBXML_CATALOG_ENABLED
+#include <libxml/catalog.h>
+#endif
 #include <libxslt/xslt.h>
 #include <libxslt/xsltInternals.h>
 #include <libxslt/transform.h>
@@ -66,6 +79,7 @@ xsltNoNetExternalEntityLoader(const char *URL, const char *ID,
 static void usage(const char *name) {
     printf("Usage: %s [options] stylesheet file [file ...]\n", name);
     printf("   Options:\n");
+    printf("      --version or -V: show the version of libxml and libxslt used\n");
     printf("      --verbose or -v: show logs of what's happening\n");
     printf("      --timing: display the time used\n");
     printf("      --repeat: run the transformation 20 times\n");
@@ -79,9 +93,15 @@ static void usage(const char *name) {
 #ifdef LIBXML_DOCB_ENABLED
     printf("      --docbook: the input document is SGML docbook\n");
 #endif
-    printf("      --param name value\n");
+    printf("      --param name value : pass a (parameter,value) pair\n");
     printf("      --nonet refuse to fetch DTDs or entities over network\n");
     printf("      --warnnet warn against fetching over the network\n");
+#ifdef LIBXML_CATALOG_ENABLED
+    printf("      --catalogs : use the catalogs from $SGML_CATALOG_FILES\n");
+#endif
+#ifdef LIBXML_XINCLUDE_ENABLED
+    printf("      --xinclude : do XInclude processing on document intput\n");
+#endif
 }
 
 int
@@ -115,6 +135,11 @@ main(int argc, char **argv) {
 		   (!strcmp(argv[i], "-verbose")) ||
 		   (!strcmp(argv[i], "--verbose"))) {
 	    xsltSetGenericDebugFunc(stderr, NULL);
+	} else if ((!strcmp(argv[i], "-V")) ||
+		   (!strcmp(argv[i], "-version")) ||
+		   (!strcmp(argv[i], "--version"))) {
+	    printf("Using libxml %s and libxslt %s\n",
+		   xmlParserVersion, xsltEngineVersion);
 	} else if ((!strcmp(argv[i], "-repeat")) ||
 		   (!strcmp(argv[i], "--repeat"))) {
 	    if (repeat == 0)
@@ -147,6 +172,18 @@ main(int argc, char **argv) {
 		   (!strcmp(argv[i], "--nonet"))) {
 	    xmlSetExternalEntityLoader(xsltNoNetExternalEntityLoader);
 	    nonet = 1;
+#ifdef LIBXML_CATALOG_ENABLED
+	} else if ((!strcmp(argv[i], "-catalogs")) ||
+		 (!strcmp(argv[i], "--catalogs"))) {
+	    const char *catalogs;
+
+	    catalogs = getenv("SGML_CATALOG_FILES");
+	    if (catalogs == NULL) {
+		fprintf(stderr, "Variable $SGML_CATALOG_FILES not set\n");
+	    } else {
+		xmlLoadCatalogs(catalogs);
+	    }
+#endif
 #ifdef LIBXML_XINCLUDE_ENABLED
 	} else if ((!strcmp(argv[i], "-xinclude")) ||
 		   (!strcmp(argv[i], "--xinclude"))) {
@@ -177,8 +214,8 @@ main(int argc, char **argv) {
     }
     params[nbparams] = NULL;
     xmlSubstituteEntitiesDefault(1);
-    if (novalid == 0)
-	xmlLoadExtDtdDefaultValue = 1;
+    if (novalid == 0) /* TODO XML_DETECT_IDS | XML_COMPLETE_ATTRS */
+	xmlLoadExtDtdDefaultValue = 6;
     else
 	xmlLoadExtDtdDefaultValue = 0;
     for (i = 1; i < argc ; i++) {
